@@ -7,5 +7,5 @@ mkdir $DIR
 tar -xf $3 --strip 2 -C $DIR
 rm $3
 
-XZ_OPT=--best tar -cJvf $TAR --exclude '.gitignore' --exclude 'doclava-style' --exclude 'leftovers' --exclude 'bin' $DIR
+XZ_OPT=--best tar -cJvf $TAR --exclude '.gitignore' --exclude 'doclava' --exclude 'leftovers' --exclude 'bin' $DIR
 rm -Rf $DIR
